@@ -47,7 +47,7 @@ package FP::Abstract::Pure;
 
 use strict; use warnings; use warnings FATAL => 'uninitialized';
 
-sub fp_interface_method_names {
+sub FP_Interface__method_names {
     ()
 }
 
