@@ -37,7 +37,8 @@ Should this module stay? Vote your opinion if you like.
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
